@@ -1,5 +1,6 @@
 import time
 import os
+from pathlib import Path
 import numpy as nump
 import pandas as panda
 import uuid
@@ -95,7 +96,7 @@ class Log:
         total_cts = 1
         passed = 1 if result else 0
         failed = 0 if result else 1
-        printable_message = ''.join(filter(lambda x: x.isprintable(), message))[:650]
+        printable_message = self.printable_message(message)
 
         if not self.suite_datetime:
             self.suite_datetime = time.strftime("%d/%m/%Y %X")
@@ -119,10 +120,10 @@ class Log:
         if len(self.table_rows) > 0:
             try:
                 if self.folder:
-                    path = f"{self.folder}\\{self.station}_v6"
+                    path = Path(self.folder, self.station+"_v6")
                     os.makedirs(path)
                 else:
-                    path = f"Log\\{self.station}"
+                    path = Path("Log", self.station)
                     os.makedirs(path)
             except OSError:
                 pass
@@ -131,14 +132,14 @@ class Log:
                 open("log_exec_file.txt", "w")
 
             if ((len(self.table_rows[1:]) == len(self.test_case) and self.get_testcase_stack() not in self.csv_log) or (self.get_testcase_stack() == "setUpClass") and self.checks_empty_line()) :
-                with open(f"{path}\\{log_file}", mode="w", newline="", encoding="windows-1252") as csv_file:
+                with open( Path(path, log_file), mode="w", newline="", encoding="windows-1252") as csv_file:
                     csv_writer_header = csv.writer(csv_file, delimiter=';', quoting=csv.QUOTE_NONE)
                     csv_writer_header.writerow(self.table_rows[0])
                     csv_writer = csv.writer(csv_file, delimiter=';', quotechar='"', quoting=csv.QUOTE_NONNUMERIC)
                     for line in self.table_rows[1:]:
                         csv_writer.writerow(line)
 
-                print(f"Log file created successfully: {path}\\{log_file}")
+                print(f"Log file created successfully: {os.path.join(path, log_file)}")
                             
                 self.csv_log.append(self.get_testcase_stack())
 
@@ -223,7 +224,7 @@ class Log:
         >>> # Calling the method:
         >>> self.log.generate_result(True, "Success")
         """
-        printable_message = ''.join(filter(lambda x: x.isprintable(), message))[:650]
+        printable_message = self.printable_message(message)
 
         if not self.suite_datetime:
             self.suite_datetime = time.strftime("%d/%m/%Y %X")
@@ -353,13 +354,12 @@ class Log:
         today = datetime.today()
         
         try:
-            path = f"{self.folder}\\new_log\\{self.station}"
+            path = Path(self.folder, "new_log", self.station)
             os.makedirs(path)
         except OSError:
             pass
-
         try:
-            with open(f"{path}\\response_log.csv", mode="a", encoding="utf-8", newline='') as response_log:
+            with open( Path(path, "response_log.csv"), mode="a", encoding="utf-8", newline='') as response_log:
                 csv_write = csv.writer(response_log, delimiter=';', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                 csv_write.writerow([f"Time: {today.strftime('%Y%m%d%H%M%S%f')[:-3]}", f"URL: {server_address}", f"CT: {json.loads(json_data)['CTMETHOD']}",
                                     {f"Status Code: {response.status_code}"}, f"Message: {response.text}"])
@@ -378,10 +378,10 @@ class Log:
 
         try:
             if self.folder:
-                path = f"{self.folder}\\new_log\\{self.station}"
+                path = Path(self.folder, "new_log", self.station)
                 os.makedirs(path)
             else:
-                path = f"Log\\{self.station}"
+                path = Path("Log", self.station)
                 os.makedirs(path)
         except OSError:
             pass
@@ -391,10 +391,10 @@ class Log:
         if self.config.smart_test:
             open("log_exec_file.txt", "w")
 
-        with open(f"{path}\\{log_file}", mode="w", encoding="utf-8") as json_file:
+        with open( Path(path, log_file), mode="w", encoding="utf-8") as json_file:
             json_file.write(json_data)
 
-        print(f"Log file created successfully: {path}\\{log_file}")
+        print(f"Log file created successfully: {Path(path, log_file)}")
 
     def ident_test(self):
         """
@@ -424,28 +424,86 @@ class Log:
         >>> # Calling the method:
         >>> self.log.take_screenshot_log()
         """
+
         if not stack_item:
             stack_item = self.get_testcase_stack()
+
+        if stack_item == "setUpClass":
+            stack_item = self.get_file_name("testsuite")
+
         if not test_number:
             test_number = f"{stack_item.split('_')[-1]} -" if stack_item else ""
 
-        log_file = f"{self.user}_{uuid.uuid4().hex}_{stack_item} error.png"
+        if not self.release:
+            self.release = self.config.release
+
+        testsuite = self.get_file_name("testsuite")
+
+        today = datetime.today()
+
+        if self.search_stack("log_error"):
+            screenshot_file = self.screenshot_file_name("error", stack_item)
+        elif self.search_stack("CheckResult"):
+            screenshot_file = self.screenshot_file_name("CheckResult_result_divergence", stack_item)
+        else:
+            screenshot_file = self.screenshot_file_name(stack_item)
 
         if self.config.debug_log:
             print(f"take_screenshot_log in:{datetime.now()}\n")
             
         try:
-            if self.config.log_folder:
-                path = f"{self.folder}\\{self.station}\\{log_file}"
-                os.makedirs(f"{self.folder}\\{self.station}")
+            if self.config.log_http:
+                folder_path = Path(self.config.log_http, self.config.country, self.release, self.config.issue, self.config.execution_id, testsuite)
+                path = Path(folder_path, screenshot_file)
+                os.makedirs(Path(folder_path))
             else:
-                path = f"Log\\{self.station}\\{log_file}"
-                os.makedirs(f"Log\\{self.station}")
+                path = Path("Log", self.station, screenshot_file)
+                os.makedirs(Path("Log", self.station))
         except OSError:
             pass
-        
-        if self.get_testcase_stack() not in self.test_case_log:
-            try:
-                driver.save_screenshot(path)
-            except Exception as e:
-                print(f"Warning Log Error save_screenshot exception {str(e)}")
\ No newline at end of file
+
+        try:
+            driver.save_screenshot(str(path))
+            print(f"Screenshot file created successfully: {path}")
+        except Exception as e:
+            print(f"Warning Log Error save_screenshot exception {str(e)}")
+
+    def screenshot_file_name(self, description="", stack_item=""):
+        """
+
+        :param name:
+        :return:
+        """
+
+        today = datetime.today()
+
+        if description:
+            return f"{self.user}_{today.strftime('%Y%m%d%H%M%S%f')[:-3]}_{stack_item}_{description}.png"
+        else:
+            return f"{self.user}_{today.strftime('%Y%m%d%H%M%S%f')[:-3]}_{stack_item}.png"
+
+    def printable_message(self, string):
+        """
+
+        :param string:
+        :return:
+        """
+
+        return re.sub(';', ',', ''.join(filter(lambda x: x.isprintable(), string))[:600])
+
+    def search_stack(self, function):
+        """
+        Returns True if passed function is present in the call stack.
+
+        :param function: Name of the function
+        :type function: str
+
+        :return: Boolean if passed function is present or not in the call stack.
+        :rtype: bool
+
+        Usage:
+
+        >>> # Calling the method:
+        >>> is_present = self.search_stack("MATA020")
+        """
+        return len(list(filter(lambda x: x.function == function, inspect.stack()))) > 0
